@@ -9,7 +9,7 @@ logger.setLevel(logging.DEBUG)
 
 formatter = logging.Formatter(fmt='%(asctime)s - %(name)s - %(levelname)s - %(filename)s:%(lineno)s - %(funcName)2s() - %(message)s')
 
-file_handler = logging.FileHandler(filename='/var/log/ruby_file_formatter.log', mode='w')
+file_handler = logging.FileHandler(filename='./ruby_file_formatter.log', mode='w')
 file_handler.setLevel(logging.DEBUG)
 file_handler.setFormatter(formatter)
 
